/* "The Structure of Tariffs and Long-Term Growth", AEJ Macro, Graphs */

version 10.1
capture clear
capture log close
set mem 200m
set more off

log using "AEJ_Macro_graphs.log", replace

set scheme s2gmanual

use "AEJ_Macro_data_final.dta", clear
egen tag=tag(wbcode)
tab tag
drop if tag==0
drop tag
gen pos=3

***************************************************************
*** Figure 1a: Partial correlation plot for Rho and Growth  ***
***************************************************************
preserve
reg growth skill1_corr avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla
avplot skill1_corr, rlopts(lwidth(thick)) msymbol(o) mlabel(wbcode) mlabv(pos) xlabel(-.45 .1 .55, nogrid) ylabel(-.03 .01 .04, nogrid) title("") note("(coef = .035, t-stat = 3.50)") ytitle("E(Average Annual Growth in Real Per Capita GDP | X)") xtitle("E(Rho | X)") scale(.8) 
graph export "partial_plot_rho.eps", as(eps) preview(off) replace fontface(Times)
restore

****************************************************************
*** Figure 1b: Partial correlation plot for Diffa and Growth ***
****************************************************************
preserve
reg growth diffa ln_init_q_skilla ln_init_q_unskilla avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87
avplot diffa, rlopts(lwidth(thick)) msymbol(o) mlabel(wbcode) mlabv(pos) xlabel(-.9 .05 1.1, nogrid) ylabel(-.03 .01 .05, nogrid) title("") note("(coef = .016, t-stat = 3.29)") ytitle("E(Average Annual Growth in Real Per Capita GDP | X)") xtitle("E(DIFF(Low) | X)") scale(.8) 
graph export "partial_plot_diffa.eps", as(eps) preview(off) replace fontface(Times)
restore

***************************************************
*** Figures 2a: Control of corruption and Diffa ***
***************************************************
reg diffa control_corrup2000, beta
predict hat
twoway (scatter diffa control_corrup2000, msymbol(O) mlabel(wbcode)) (line hat control_corrup2000, sort clwidth(thick)), legend(off) xlabel(-2 -1 0 1 2 3, nogrid) ylabel(-1.5 0 1.5, nogrid) ytitle("Low cut-off DIFF") xtitle("Control of Corruption") note("(Beta = .68, t = 7.23, N = 63)") scale(.8) 
graph export "diffa_control_corrup2000_bivariate_graph.eps", as(eps) preview(off) replace fontface(Times)
drop hat

***********************************************************
*** Figures 2b: Control of corruption and Diffa in 2000 ***
***********************************************************
preserve
keep if (wto_year<final_year) | (gatt_year<final_year)
reg fin_diffa control_corrup2000, beta
predict hat
twoway (scatter fin_diffa control_corrup2000, msymbol(O) mlabel(wbcode)) (line hat control_corrup2000, sort clwidth(thick)), legend(off) xlabel(-2 -1 0 1 2 3, nogrid) ylabel(-1.5 0 1.5, nogrid) ytitle("Low cut-off DIFF (measured in final period)") xtitle("Control of Corruption") note("(Beta = .13, t = 0.97, N = 56)") scale(.8) 
graph export "fin_diffa_control_corrup2000_bivariate_graph.eps", as(eps) preview(off) replace fontface(Times)
drop hat
restore

***********************************
*** Figure 3a: Parking Tickets  ***
***********************************
reg  diffa ln_viol_per_car, beta
predict hat
twoway (scatter diffa ln_viol_per_car, msymbol(O) mlabel(wbcode)) (line hat ln_viol_per_car, sort clwidth(thick)), legend(off) xlabel(-.5  2.5 5.5, nogrid) ylabel(-1.5 0 1.5, nogrid) ytitle("Low cut-off DIFF") xtitle("Log parking violations per car per year") note("(Beta = -.53, t = 4.73, N = 59)")  scale(.8) 
graph export "diffa_parking_violations_bivariate_graph.eps", as(eps) preview(off) replace fontface(Times)
drop hat

****************************************
*** Figure 3b: Political Connections ***
****************************************
reg diffa percent_firms_connected, beta 
predict hat
twoway (scatter diffa percent_firms_connected, msymbol(O) mlabel(wbcode)) (line hat percent_firms_connected, sort clwidth(thick)), legend(off) xlabel(0 12 24, nogrid) ylabel(-1.5 0 1.5, nogrid) ytitle("Low cut-off DIFF") xtitle("Percent of Firms Politically Connected") note("(Beta = -.34, t = 2.06, N = 35)") scale(.8) 
graph export "diffa_political_connections.eps", as(eps) preview(off) replace fontface(Times)
drop hat

log close




