/* Regressions for the "The Structure of Tariffs and Long-Term Growth", AEJ: Macro */

version 10.0
capture clear
capture log close
set mem 200m
set more off

use "AEJ_Macro_data_final.dta", clear

log using "AEJ_Macro_tables.log", replace

local governance_controls "voice2000 political_stability2000 govt_effectiveness2000 reg_quality2000 rule_of_law2000 control_corrup2000"


************ TABLE 1: Showing Industries and Cut-Offs ******************


*****************************************************************
************ TABLE 2: Tariff Mean and Variance ******************
*****************************************************************

reg growth avg_tar init inv human_cap dum80_83 dum85_87 if industry=="211212"
reg growth avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 if industry=="211212"


************ TABLE 3: Showing Countries in Sample ******************


**************************************************************
*********** TABLE 4: Country Growth Regressions **************
**************************************************************
reg growth skill1_corr  avg_tar init inv human_cap *_africa n_afr_me e_europe lat_america *_asia dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"

reg growth diffa avg_tar       init inv human_cap *_africa n_afr_me e_europe lat_america *_asia dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth tskilla tnoskilla   init inv human_cap *_africa n_afr_me e_europe lat_america *_asia dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"

reg growth diffg avg_tar       init inv human_cap *_africa n_afr_me e_europe lat_america *_asia dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"
reg growth tskillg tnoskillg   init inv human_cap *_africa n_afr_me e_europe lat_america *_asia dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"


*************************************************************
********** TABLE 5: Industry Output Regressions *************
*************************************************************

xi: reg prod_growth skill1_corr avg_tar init ln_init_q inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla i.industry, cluster(wbcode)
xi: reg prod_growth diffa avg_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth tskilla tnoskilla ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffg avg_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)
xi: reg prod_growth tskillg tnoskillg ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)


****************************************************************************************************
********** TABLE 6: Industry Output Regressions, Controlling for Own Industry Channels *************
****************************************************************************************************
gen init_tar_x_skill=init_tar*skill_2_1

xi: reg prod_growth skill1_corr avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla i.industry, cluster(wbcode)
xi: reg prod_growth skill1_corr avg_tar init_tar init_tar_x_skill ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla i.industry, cluster(wbcode)

xi: reg prod_growth diffa avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffa avg_tar init_tar init_tar_x_skill ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)

xi: reg prod_growth tskilla tnoskilla init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth tskilla tnoskilla init_tar init_tar_x_skill ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)

xi: reg prod_growth diffg avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)
xi: reg prod_growth diffg avg_tar init_tar init_tar_x_skill ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)

xi: reg prod_growth tskillg tnoskillg init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)
xi: reg prod_growth tskillg tnoskillg init_tar init_tar_x_skill ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)

/* Footnote: including country FEs */
xi: areg prod_growth init_tar ln_init_q i.wbcode, absorb(industry)


********************************************************************************
******** TABLE 7: Controlling for Changes in Industrial Structure **************
********************************************************************************

reg diff_growth_q_a skill1_corr init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg diff_growth_q_a diffa       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg diff_growth_q_g diffg       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"

reg growth diff_growth_q_a avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diff_growth_q_g avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"

reg growth skill1_corr diff_growth_q_a avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa       diff_growth_q_a avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg       diff_growth_q_g avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"


***************************************************************************
******** TABLE 8: Controlling for Human Capital Accumulation **************
***************************************************************************

reg growth_human_cap skill1_corr init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth_human_cap diffa 	 init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth_human_cap diffg 	 init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"

reg growth skill1_corr growth_human_cap  avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa       growth_human_cap  avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg       growth_human_cap  avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"


*******************************************************************
******** TABLE 9: Controlling for Knowledge Creation **************
*******************************************************************

reg patent_growth skill1_corr init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg patent_growth diffa       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg patent_growth diffg       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"

reg growth skill1_corr patent_growth avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa       patent_growth avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg       patent_growth avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"


**************************************************************************
*********** TABLE 10: Including Governance Matters Variables **************
**************************************************************************

/* Country Regressions */
reg growth skill1_corr avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla `governance_controls' if industry=="211212"
reg growth diffa avg_tar       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla `governance_controls' if industry=="211212"
reg growth tskilla tnoskilla   init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla `governance_controls' if industry=="211212"
reg growth diffg avg_tar       init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg `governance_controls' if industry=="211212"
reg growth tskillg tnoskillg   init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg `governance_controls' if industry=="211212"


*************************************************************************
********** TABLE 11: Alternative Cut-offs and Skill Mesaures *************
*************************************************************************

/* See separate do file */


************************************************************
********** TABLE 12: Robustness and Sensitivity *************
************************************************************

************************
* Baseline Regressions *
************************
/* Country Growth Regressions */
reg growth skill1_corr  avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa 	avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg 	avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"
/* Industry Output Regressions */
xi: reg prod_growth skill1_corr avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla i.industry, cluster(wbcode)
xi: reg prod_growth diffa 	avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffg 	avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)

************************
* Omitting Agriculture *
************************
preserve
use "AEJ_Macro_data_no_agriculture_final.dta", clear
/* Country Growth Regressions */
reg growth skill1_corr  avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa 	avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg 	avg_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"
/* Industry Output Regressions */
xi: reg prod_growth skill1_corr avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla i.industry, cluster(wbcode)
xi: reg prod_growth diffa 	avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffg 	avg_tar init_tar ln_init_q init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)
restore

*************************************
* Omitting the 10 Richest Countries *
*************************************
/* Country Growth Regressions */
preserve
for @ in any SGP FRA NLD NZL SWE HKG CAN AUS DNK USA: drop if wbcode=="@"
reg growth skill1_corr avg_tar        init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffa  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if industry=="211212"
reg growth diffg  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if industry=="211212"
/* Industry Output Regressions */
xi: reg prod_growth skill1_corr avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffa avg_tar 	 init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla, cluster(wbcode)
xi: reg prod_growth diffg avg_tar 	 init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q ln_init_q_skillg ln_init_q_unskillg, cluster(wbcode)
restore

*******************************************************
* Omitting influential observations - Welsch distance *
*******************************************************
/* Country Growth Regressions */
preserve
keep if industry=="211212"
reg growth skill1_corr avg_tar        init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla 
predict welsch if e(sample), welsch
tab wbcode if welsch>=(3*sqrt(20))
reg growth skill1_corr avg_tar        init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if welsch<(3*sqrt(20))		/* 3*sqrt(k) */
restore
preserve
keep if industry=="211212"
reg growth diffa  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla
predict welsch if e(sample), welsch
tab wbcode if welsch>=(3*sqrt(20))
reg growth diffa  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skilla ln_init_q_unskilla if welsch<(3*sqrt(20))		/* 3*sqrt(k) */
restore
preserve
keep if industry=="211212"
reg growth diffg  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg
predict welsch if e(sample), welsch
tab wbcode if welsch>=(3*sqrt(20))
reg growth diffg  avg_tar             init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 ln_init_q_skillg ln_init_q_unskillg if welsch<(3*sqrt(20))		/* 3*sqrt(k) */
restore
/* Industry Output Regressions */
preserve
xi: reg prod_growth skill1_corr avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla
predict welsch if e(sample), welsch
xi: reg prod_growth skill1_corr avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla if welsch<(3*sqrt(38)), cluster(wbcode)		/* 3*sqrt(k) */
restore
preserve
xi: reg prod_growth diffa avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla
predict welsch if e(sample), welsch
xi: reg prod_growth diffa avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skilla ln_init_q_unskilla if welsch<(3*sqrt(38)), cluster(wbcode)			/* 3*sqrt(k) */
restore
preserve
xi: reg prod_growth diffg avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skillg ln_init_q_unskillg
predict welsch if e(sample), welsch
xi: reg prod_growth diffg avg_tar  init_tar init inv human_cap *_africa n_afr_me lat_america *_asia e_europe dum80_83 dum85_87 i.industry ln_init_q ln_init_q_skillg ln_init_q_unskillg if welsch<(3*sqrt(38)), cluster(wbcode)			/* 3*sqrt(k) */
restore


*****************************************************************
*********** Appdendix table 13: Summary Statistics **************
*****************************************************************

/* Country level */
preserve
egen tag=tag(wbcode)
drop if tag==0
sum growth
sum skill1_corr tskilla tnoskilla diffa ln_init_q_skilla ln_init_q_unskilla if missing(growth)!=1
sum tskillg tnoskillg diffg ln_init_q_skillg ln_init_q_unskillg if missing(growth)!=1
sum init inv human_cap avg_tar if missing(growth)!=1
restore

/* Industry level */
sum prod_growth
sum skill1_corr tskilla tnoskilla diffa ln_init_q_skilla ln_init_q_unskilla if missing(prod_growth)!=1
sum tskillg tnoskillg diffg ln_init_q_skillg ln_init_q_unskillg if missing(prod_growth)!=1
sum init inv human_cap avg_tar init_tar ln_init_q if missing(prod_growth)!=1

log close


